@@ -5,7 +5,7 @@ from pathlib import Path
 from collections import namedtuple
 from argparse import ArgumentParser, RawTextHelpFormatter, RawDescriptionHelpFormatter
 
-from das.modules.add import AddMasscanOutput, AddRustscanOutput, AddNaabuOutput
+from das.modules.add import AddMasscanOutput, AddRustscanOutput, AddNaabuOutput, AddNmapOutput
 from das.modules.scan import ScanShow, ScanRun
 from das.modules.report import NmapMerger
 from das.modules.common import BANNER, Logger
@@ -25,11 +25,12 @@ def parse_args():
 	add_epilog = """
 	examples:
 
-	  das add masscan '-e eth0 --rate 1000 -iL hosts.txt --open -p1-65535'
+	  das add masscan '-e eth0 --rate 1000 -iL hosts.txt -p1-65535 --open'
 	  das add rustscan '-b 1000 -t 2000 -u 5000 -a hosts.txt -r 1-65535 -g --no-config --scan-order "Random"'
 	  das add -db testdb -rm naabu '-interface eth0 -rate 1000 -iL hosts.txt -p - -silent -s s'
+	  das add nmap '-v -n -Pn --min-rate 1000 -T4 -iL hosts.txt -p1-49151 --open'
 	""".replace('\t', '')
-	add_parser = subparser.add_parser('add', formatter_class=RawDescriptionHelpFormatter, epilog=add_epilog, help='run a full port scan {masscan,rustscan,naabu} and add the output to DB')
+	add_parser = subparser.add_parser('add', formatter_class=RawDescriptionHelpFormatter, epilog=add_epilog, help='run a full port scan {masscan,rustscan,naabu,nmap} and add the output to DB')
 	add_parser.add_argument('scanner_name', action='store', type=str, help='port scanner name')
 	add_parser.add_argument('scanner_args', action='store', type=str, help='port scanner switches and options')
 	add_parser.add_argument('-db', action='store', type=str, default='das', help='DB name to save the output into')
@@ -106,6 +107,8 @@ def main():
 			AddPortscanOutput = AddRustscanOutput
 		elif args.scanner_name == 'naabu':
 			AddPortscanOutput = AddNaabuOutput
+		elif args.scanner_name == 'nmap':
+			AddPortscanOutput = AddNmapOutput
 		else:
 			logger.print_error(f'{args.scanner_name}: Unsupported port scanner')
 			sys.exit(1)
